"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const selenium_webdriver_1 = require("selenium-webdriver");
/* https://github.com/SeleniumHQ/selenium/issues/2969#issuecomment-307917606 */
selenium_webdriver_1.promise.USE_PROMISE_MANAGER = false;
/**
 * `import {SeleniumAdapter} from '@pageobject/selenium-adapter';`
 */
class SeleniumAdapter {
    static async launchHeadlessChrome() {
        const capabilities = selenium_webdriver_1.Capabilities.chrome().set('chromeOptions', {
            args: ['--headless', '--disable-gpu']
        });
        /* tslint:disable-next-line await-promise */
        const driver = await new selenium_webdriver_1.Builder().withCapabilities(capabilities).build();
        return new SeleniumAdapter(driver);
    }
    constructor(driver) {
        this.driver = driver;
    }
    async click(element) {
        await element.click();
    }
    /* tslint:disable no-any */
    async evaluate(script, ...args) {
        return this.driver.executeScript(script, ...args);
    }
    /* tslint:enable no-any */
    async findElements(selector, parent) {
        return (parent || this.driver).findElements(selenium_webdriver_1.By.css(selector));
    }
    async takeScreenshot() {
        return this.driver.takeScreenshot();
    }
    async type(element, text, delay) {
        for (const character of text.split('')) {
            await element.sendKeys(character);
            await new Promise(resolve => setTimeout(resolve, delay));
        }
    }
}
exports.SeleniumAdapter = SeleniumAdapter;
//# sourceMappingURL=index.js.map